Struct matroska::Chapter
[−]
[src]
pub struct Chapter {
pub time_start: Duration,
pub time_end: Option<Duration>,
pub hidden: bool,
pub enabled: bool,
pub display: Vec<ChapterDisplay>,
}An individual chapter point
Fields
time_start: Duration
Timestamp of the start of the chapter
time_end: Option<Duration>
Timestamp of the end of the chapter
Whether the chapter point should be hidden in the user interface
enabled: bool
Whether the chapter point should be enabled in the user interface
display: Vec<ChapterDisplay>
Contains all strings to use for displaying chapter